Installation
============

.. note::
   **Warning:** This tool is not yet published on PyPI, but it will be available soon. 
   In the meantime, please use the installation from the local Git repository.


Prerequisites
-------------

* `pip <https://pip.pypa.io/en/stable/>`_ or `uv <https://docs.astral.sh/uv/>`_


Installation with pip
---------------------

**1. Install from PyPI:**

.. code-block:: bash

   pip install denofo

**2. Install from the local Git repository:**

.. code-block:: bash

   git clone https://github.com/EDohmen/denofo.git
   cd denofo
   pip install -e .


Installation with uv
--------------------

**1. Install from PyPI:**

.. code-block:: bash

   uv pip install denofo

**2. Install from the local Git repository:**

.. code-block:: bash

   git clone https://github.com/EDohmen/denofo.git
   cd denofo
   uv pip install -e .

After installation, you can access the tools via the command line: :doc:`Usage <usage>`.